@@ -9,8 +9,8 @@ summary(DisturbedDreams)
 ## -----------------------------------------------------------------------------
 mod_ref_log_c <- GLMcat(
   formula = Level ~ Age, ratio = "reference",
-  distribution = "logistic", ref_category = "Very.severe",
-  data = DisturbedDreams,
+  cdf = "logistic", ref_category = "Very.severe",
+  data = DisturbedDreams
 )
 
 ## -----------------------------------------------------------------------------
@@ -45,8 +45,8 @@ predict_glmcat(mod_ref_log_c, data = Age, type = "prob")
 
 ## -----------------------------------------------------------------------------
 mod2 <- GLMcat(
-  formula = Level ~ Age, distribution = "logistic",
-  proportional = "Age", ref_category = "Very.severe",
+  formula = Level ~ Age, cdf = "logistic",
+  parallel = "Age", ref_category = "Very.severe",
   data = DisturbedDreams
 )
 summary(mod2)
@@ -55,7 +55,7 @@ logLik(mod2)
 ## -----------------------------------------------------------------------------
 mod3 <- GLMcat(
   formula = Level ~ Age, ref_category = "Very.severe",
-  data = DisturbedDreams, distribution = "student", freedom_degrees = 0.5
+  data = DisturbedDreams, cdf = student.glmcat(df = 0.5)
 )
 summary(mod3)
 logLik(mod3)
@@ -64,7 +64,7 @@ logLik(mod3)
 logLik(mod_ref_log_c) # recall (ref,logit,com)
 mod_adj_log_c <- GLMcat(
   formula = Level ~ Age, ratio = "adjacent",
-  data = DisturbedDreams, distribution = "logistic"
+  data = DisturbedDreams, cdf = "logistic"
 )
 logLik(mod_adj_log_c)
 summary(mod_adj_log_c)
@@ -76,7 +76,7 @@ summary(mod_adj_log_c)
 ## -----------------------------------------------------------------------------
 mod_adj_cau_c <- GLMcat(
   formula = Level ~ Age,
-  ratio = "adjacent", distribution = "cauchit",
+  ratio = "adjacent", cdf = "cauchy",
   categories_order = c("Not.severe", "Severe.1", "Severe.2", "Very.severe"),
   data = DisturbedDreams
 )
@@ -86,7 +86,7 @@ summary(mod_adj_cau_c)
 ## -----------------------------------------------------------------------------
 mod_adj_cau_c_rev <- GLMcat(
   formula = Level ~ Age,
-  ratio = "adjacent", distribution = "cauchit",
+  ratio = "adjacent", cdf = "cauchy",
   categories_order = c("Very.severe", "Severe.2", "Severe.1", "Not.severe"),
   data = DisturbedDreams
 )
@@ -96,9 +96,9 @@ summary(mod_adj_cau_c_rev)
 ## -----------------------------------------------------------------------------
 adj_gumbel_p <- GLMcat(
   formula = Level ~ Age,
-  ratio = "adjacent", distribution = "gumbel",
+  ratio = "adjacent", cdf = "gumbel",
   categories_order = c("Not.severe", "Severe.1", "Severe.2", "Very.severe"),
-  proportional = c("(Intercept)", "Age"),
+  parallel = c("(Intercept)", "Age"),
   data = DisturbedDreams
 )
 logLik(adj_gumbel_p)
@@ -107,9 +107,9 @@ summary(adj_gumbel_p)
 ## -----------------------------------------------------------------------------
 adj_gompertz_rev <- GLMcat(
   formula = Level ~ Age,
-  ratio = "adjacent", distribution = "gompertz",
+  ratio = "adjacent", cdf = "gompertz",
   categories_order = c("Very.severe", "Severe.2", "Severe.1", "Not.severe"),
-  proportional = c("(Intercept)", "Age"),
+  parallel = c("(Intercept)", "Age"),
   data = DisturbedDreams
 )
 logLik(adj_gompertz_rev)
@@ -118,7 +118,7 @@ summary(adj_gompertz_rev)
 ## -----------------------------------------------------------------------------
 seq_probit_c <- GLMcat(
   formula = Level ~ Age,
-  ratio = "sequential", distribution = "normal",
+  ratio = "sequential", cdf = "normal",
   data = DisturbedDreams
 )
 logLik(seq_probit_c)
@@ -127,7 +127,7 @@ summary(seq_probit_c)
 ## -----------------------------------------------------------------------------
 cum_log_co <- GLMcat(
   formula = Level ~ Age,
-  distribution = "logistic",
+  cdf = "logistic",
   ratio = "cumulative",
   data = DisturbedDreams
 )
@@ -137,10 +137,10 @@ summary(cum_log_co)
 ## -----------------------------------------------------------------------------
 cum_log_co_e <- GLMcat(
   formula = Level ~ Age,
-  distribution = "logistic",
+  cdf = "logistic",
   ratio = "cumulative",
   data = DisturbedDreams,
-  proportional = "Age",
+  parallel = "Age",
   threshold = "equidistant",
 )
 logLik(cum_log_co_e)
@@ -149,10 +149,10 @@ summary(cum_log_co_e)
 ## -----------------------------------------------------------------------------
 cum_log_c <- GLMcat(
   formula = Level ~ Age,
-  distribution = "student", freedom_degrees = 0.8,
+  cdf = student.glmcat(df = 0.8),
   ratio = "cumulative",
   data = DisturbedDreams,
-  beta_init = coef(cum_log_co),
+  control = control.glmcat(beta_init = coef(cum_log_co))
 )
 logLik(cum_log_c)
 summary(cum_log_c)
@@ -160,20 +160,20 @@ summary(cum_log_c)
 ## -----------------------------------------------------------------------------
 cum_gom_p <- GLMcat(
   formula = Level ~ Age,
-  distribution = "gompertz",
+  cdf = "gompertz",
   ratio = "cumulative",
   data = DisturbedDreams,
-  proportional = "Age"
+  parallel = "Age"
 )
 logLik(cum_gom_p)
 summary(cum_gom_p)
 
 seq_gom_p <- GLMcat(
   formula = Level ~ Age,
-  distribution = "gompertz",
+  cdf = "gompertz",
   ratio = "sequential",
   data = DisturbedDreams,
-  proportional = "Age"
+  parallel = "Age"
 )
 logLik(seq_gom_p)
 summary(seq_gom_p)
